Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1114)

Unified Diff: snapshot/win/system_snapshot_win.h

Issue 936333004: win: Add implementation of system_snapshot for Windows (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@add-time-win
Patch Set: fixes Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « snapshot/win/process_reader_win.cc ('k') | snapshot/win/system_snapshot_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: snapshot/win/system_snapshot_win.h
diff --git a/snapshot/mac/system_snapshot_mac.h b/snapshot/win/system_snapshot_win.h
similarity index 64%
copy from snapshot/mac/system_snapshot_mac.h
copy to snapshot/win/system_snapshot_win.h
index edbd74fb96696518d1c9ef74f29481f2af2bc4f2..b7a22c6ad0b9192f3f20abde89a30d59502f056c 100644
--- a/snapshot/mac/system_snapshot_mac.h
+++ b/snapshot/win/system_snapshot_win.h
@@ -1,4 +1,4 @@
-// Copyright 2014 The Crashpad Authors. All rights reserved.
+// Copyright 2015 The Crashpad Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
@@ -12,49 +12,43 @@
// See the License for the specific language governing permissions and
// limitations under the License.
-#ifndef CRASHPAD_SNAPSHOT_MAC_SYSTEM_SNAPSHOT_MAC_H_
-#define CRASHPAD_SNAPSHOT_MAC_SYSTEM_SNAPSHOT_MAC_H_
+#ifndef CRASHPAD_SNAPSHOT_WIN_SYSTEM_SNAPSHOT_WIN_H_
+#define CRASHPAD_SNAPSHOT_WIN_SYSTEM_SNAPSHOT_WIN_H_
#include <stdint.h>
+#include <sys/time.h>
#include <string>
#include "base/basictypes.h"
#include "snapshot/system_snapshot.h"
+#include "snapshot/win/process_reader_win.h"
#include "util/misc/initialization_state_dcheck.h"
namespace crashpad {
-class ProcessReader;
+class ProcessReaderWin;
namespace internal {
-//! \brief A SystemSnapshot of the running system, when the system runs Mac OS
-//! X.
-class SystemSnapshotMac final : public SystemSnapshot {
+//! \brief A SystemSnapshot of the running system, when the system runs Windows.
+class SystemSnapshotWin final : public SystemSnapshot {
public:
- SystemSnapshotMac();
- ~SystemSnapshotMac() override;
+ SystemSnapshotWin();
+ ~SystemSnapshotWin() override;
//! \brief Initializes the object.
//!
//! \param[in] process_reader A reader for the process being snapshotted.
- //! \n\n
+ //!
//! It seems odd that a system snapshot implementation would need a
//! ProcessReader, but some of the information reported about the system
//! depends on the process it’s being reported for. For example, the
//! architecture returned by GetCPUArchitecture() should be the
//! architecture of the process, which may be different than the native
//! architecture of the system: an x86_64 system can run both x86_64 and
//! 32-bit x86 processes.
- //! \param[in] snapshot_time The time of the snapshot being taken.
- //! \n\n
- //! This parameter is necessary for TimeZone() to determine whether
- //! daylight saving time was in effect at the time the snapshot was taken.
- //! Otherwise, it would need to base its determination on the current
- //! time, which may be different than the snapshot time for snapshots
- //! generated around the daylight saving transition time.
- void Initialize(ProcessReader* process_reader, const timeval* snapshot_time);
+ void Initialize(ProcessReaderWin* process_reader);
// SystemSnapshot:
@@ -70,8 +64,10 @@ class SystemSnapshotMac final : public SystemSnapshot {
bool CPUX86SupportsDAZ() const override;
OperatingSystem GetOperatingSystem() const override;
bool OSServer() const override;
- void OSVersion(
- int* major, int* minor, int* bugfix, std::string* build) const override;
+ void OSVersion(int* major,
+ int* minor,
+ int* bugfix,
+ std::string* build) const override;
std::string OSVersionFull() const override;
bool NXEnabled() const override;
std::string MachineDescription() const override;
@@ -84,18 +80,17 @@ class SystemSnapshotMac final : public SystemSnapshot {
private:
std::string os_version_full_;
std::string os_version_build_;
- ProcessReader* process_reader_; // weak
- const timeval* snapshot_time_; // weak
+ ProcessReaderWin* process_reader_; // weak
int os_version_major_;
int os_version_minor_;
int os_version_bugfix_;
bool os_server_;
InitializationStateDcheck initialized_;
- DISALLOW_COPY_AND_ASSIGN(SystemSnapshotMac);
+ DISALLOW_COPY_AND_ASSIGN(SystemSnapshotWin);
};
} // namespace internal
} // namespace crashpad
-#endif // CRASHPAD_SNAPSHOT_MAC_SYSTEM_SNAPSHOT_MAC_H_
+#endif // CRASHPAD_SNAPSHOT_WIN_SYSTEM_SNAPSHOT_WIN_H_
« no previous file with comments | « snapshot/win/process_reader_win.cc ('k') | snapshot/win/system_snapshot_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -12,49 +12,43 @@
//! It seems odd that a system snapshot implementation would need a
- //! ProcessReader, but some of the information reported about the system
- //! depends on the process it’s being reported for. For example, the
- //! architecture returned by GetCPUArchitecture() should be the
+ //! ProcessReaderWin, but some of the information reported about the
+ //! system depends on the process it's being reported for. For example,
+ //! the architecture returned by GetCPUArchitecture() should be the
//! architecture of the process, which may be different than the native
//! architecture of the system: an x86_64 system can run both x86_64 and
This is Rietveld 408576698